@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+__author__ = r'wsb310@gmail.com'
+
 import os
 import sys
 import uvicorn
@@ -8,6 +10,7 @@ os.chdir(os.path.dirname(__file__))
 sys.path.insert(0, os.path.abspath(r'../../'))
 
 from fastapi.middleware.cors import CORSMiddleware
+from fastapi_health import health
 
 from hagworm.frame.fastapi.base import DEFAULT_HEADERS, create_fastapi
 from hagworm.extend.base import Utils
@@ -25,8 +28,8 @@ app = create_fastapi(
     log_file_retention=ConfigDynamic.LogFileBackups,
     debug=ConfigDynamic.Debug,
     routes=router.routes,
-    on_startup=[DataSource.initialize],
-    on_shutdown=[DataSource.release],
+    # on_startup=[DataSource.initialize],
+    # on_shutdown=[DataSource.release],
 )
 
 app.add_middleware(
@@ -37,6 +40,8 @@ app.add_middleware(
     allow_credentials=ConfigDynamic.AllowCredentials,
 )
 
+# app.add_api_route(r'/health', health([DataSource.check_health]))
+
 
 if __name__ == r'__main__':
 
