@@ -8,7 +8,7 @@ import sys
 os.chdir(os.path.dirname(__file__))
 sys.path.insert(0, os.path.abspath(r'../'))
 
-from hagworm.frame.stress_tests import Launcher, Runner, TaskInterface
+from hagworm.frame.stress_tests import Launcher, Daemon, Runner, TaskInterface
 
 
 class Task(TaskInterface):
@@ -29,4 +29,4 @@ class Task(TaskInterface):
 
 if __name__ == r'__main__':
 
-    Launcher(subprocess=2).run(Runner(Task), 8, 32)
+    Launcher(daemon=Daemon(2)).run(Runner(Task), 8, 32)
