@@ -7,16 +7,16 @@ import weakref
 import inspect
 import asyncio
 import functools
-import traceback
 
 import async_timeout
 
 from contextlib import asynccontextmanager
 from contextvars import Context, ContextVar
 
-from hagworm.extend import base
-from hagworm.extend.cache import StackCache
-from hagworm.extend.interface import RunnableInterface
+from .. import base
+from ..error import catch_error
+from ..cache import StackCache
+from ..interface import RunnableInterface
 
 
 def install_uvloop():
@@ -250,20 +250,10 @@ class Utils(base.Utils):
 
         """
 
-        try:
-
+        with catch_error():
             async with async_timeout.timeout(timeout) as res:
                 yield res
 
-        except base.Ignore as err:
-
-            if err.throw():
-                raise err
-
-        except Exception as err:
-
-            Utils.log.exception(err)
-
 
 def async_adapter(func):
     """异步函数适配装饰器
@@ -289,17 +279,6 @@ class WeakContextVar:
     """弱引用版的上下文资源共享器
     """
 
-    _instances = {}
-
-    def __new__(cls, name):
-
-        if name in cls._instances:
-            inst = cls._instances[name]
-        else:
-            inst = cls._instances[name] = super().__new__(cls)
-
-        return inst
-
     def __init__(self, name):
 
         self._context_var = ContextVar(name, default=None)
@@ -594,42 +573,6 @@ class AsyncCirculatorForSecond(AsyncCirculator):
         await Utils.sleep(self._interval)
 
 
-class AsyncContextManager:
-    """异步上下文资源管理器
-
-    子类通过实现_context_release接口，方便的实现with语句管理上下文资源释放
-
-    """
-
-    async def __aenter__(self):
-
-        await self._context_initialize()
-
-        return self
-
-    async def __aexit__(self, exc_type, exc_value, _traceback):
-
-        await self._context_release()
-
-        if exc_type and issubclass(exc_type, base.Ignore):
-
-            return not exc_value.throw()
-
-        elif exc_value:
-
-            Utils.log.exception(exc_value)
-
-            return True
-
-    async def _context_initialize(self):
-
-        pass
-
-    async def _context_release(self):
-
-        raise NotImplementedError()
-
-
 class FuncWrapper(base.FuncWrapper):
     """非阻塞异步函数包装器
 
@@ -669,16 +612,11 @@ class AsyncFuncWrapper(base.FuncWrapper):
 
         for func in self._callables:
 
-            try:
-
+            with catch_error():
                 await Utils.awaitable_wrapper(
                     func(*args, **kwargs)
                 )
 
-            except Exception as err:
-
-                Utils.log.error(err)
-
 
 class ShareFuture:
     """共享Future装饰器
@@ -786,21 +724,3 @@ class FuncCache(ShareFuture):
                 self._cache.set(_func_sign, result)
 
         return result
-
-
-class TimeDiff:
-
-    def __init__(self):
-
-        self._start_time = self._last_check_time = Utils.timestamp(True)
-
-    def check(self):
-
-        now_time = Utils.timestamp(True)
-
-        diff_time_1 = now_time - self._start_time
-        diff_time_2 = now_time - self._last_check_time
-
-        self._last_check_time = now_time
-
-        return diff_time_1, diff_time_2
