@@ -7,7 +7,7 @@ from tempfile import TemporaryFile
 from .base import Utils
 from .task import IntervalTask
 
-from hagworm.extend.base import ContextManager
+from ..interface import ContextManager
 
 
 class _BufferAbstract:
