@@ -6,15 +6,16 @@ import os
 import sys
 import asyncio
 
-from hagworm import hagworm_slogan
-from hagworm import __version__ as hagworm_version
+from ... import hagworm_slogan
+from ... import __version__ as hagworm_version
 
-from hagworm.extend.base import catch_error
-from hagworm.extend.process import fork_processes
-from hagworm.extend.asyncio.base import install_uvloop, Utils
-from hagworm.extend.logging import DEFAULT_LOG_FILE_ROTATOR
-from hagworm.extend.interface import FunctorInterface, RunnableInterface
-from hagworm.extend.asyncio.zmq import Push, Pull
+from .base import install_uvloop, Utils
+
+from ..error import catch_error
+from ..process import fork_processes
+from ..logging import DEFAULT_LOG_FILE_ROTATOR
+from ..interface import FunctorInterface, RunnableInterface
+from ..asyncio.zmq import Push, Pull
 
 
 SIGNAL_PROTOCOL = r'tcp'
