@@ -6,6 +6,8 @@ import asyncio
 import aiomysql
 import sqlalchemy
 
+from contextvars import ContextVar
+
 from aiomysql.sa import SAConnection, Engine
 from aiomysql.sa.engine import _dialect as dialect
 
@@ -16,9 +18,10 @@ from sqlalchemy.sql.dml import Insert, Update, Delete
 
 from motor.motor_asyncio import AsyncIOMotorClient
 
-from hagworm.extend.error import MySQLReadOnlyError, MySQLClientDestroyed
+from .base import Utils, WeakContextVar, AsyncCirculator
 
-from .base import Utils, WeakContextVar, AsyncContextManager, AsyncCirculator
+from ..error import catch_error, MySQLReadOnlyError, MySQLClientDestroyed
+from ..interface import AsyncContextManager
 
 
 MONGO_POLL_WATER_LEVEL_WARNING_LINE = 0x10
@@ -114,10 +117,8 @@ class MongoPool:
 
         result = None
 
-        try:
+        with catch_error():
             result = self._pool[db_name]
-        except Exception as err:
-            Utils.log.exception(err)
 
         return result
 
@@ -143,10 +144,8 @@ class MongoDelegate:
 
         result = False
 
-        try:
+        with catch_error():
             result = bool(await self._mongo_pool._pool.server_info())
-        except Exception as err:
-            Utils.log.error(err)
 
         return result
 
@@ -310,17 +309,13 @@ class MySQLPool:
 
         client = None
 
-        try:
+        with catch_error():
 
             client = DBClient(self)
 
             if not self.health:
                 client.set_auto_release(True)
 
-        except Exception as err:
-
-            Utils.log.exception(err)
-
         return client
 
     def get_transaction(self):
@@ -330,10 +325,8 @@ class MySQLPool:
         if self._readonly:
             raise MySQLReadOnlyError()
 
-        try:
+        with catch_error():
             result = DBTransaction(self)
-        except Exception as err:
-            Utils.log.exception(err)
 
         return result
 
@@ -349,6 +342,8 @@ class MySQLDelegate:
 
         context_uuid = Utils.uuid1()
 
+        self._mysql_client_context_switch = ContextVar(f'mysql_client_{context_uuid}_switch', default=True)
+
         self._mysql_rw_client_context = WeakContextVar(f'mysql_rw_client_{context_uuid}')
         self._mysql_ro_client_context = WeakContextVar(f'mysql_ro_client_{context_uuid}')
 
@@ -361,6 +356,15 @@ class MySQLDelegate:
     def mysql_ro_pool(self):
 
         return self._mysql_ro_pool
+    @property
+    def mysql_client_context_switch(self):
+
+        return self._mysql_client_context_switch.get()
+
+    @mysql_client_context_switch.setter
+    def mysql_client_context_switch(self, val):
+
+        return self._mysql_client_context_switch.set(val)
 
     async def async_init_mysql_rw(self, *args, **kwargs):
 
@@ -410,7 +414,7 @@ class MySQLDelegate:
 
         client = None
 
-        if alone:
+        if alone or not self.mysql_client_context_switch:
 
             if readonly:
                 if self._mysql_ro_pool is not None:
@@ -469,15 +473,17 @@ class MySQLDelegate:
 
     def get_db_transaction(self):
 
-        _client = self._mysql_rw_client_context.get()
+        if self.mysql_client_context_switch:
 
-        if _client is not None:
-            Utils.create_task(_client.release())
+            _client = self._mysql_rw_client_context.get()
 
-        _client = self._mysql_ro_client_context.get()
+            if _client is not None:
+                Utils.create_task(_client.release())
 
-        if _client is not None:
-            Utils.create_task(_client.release())
+            _client = self._mysql_ro_client_context.get()
+
+            if _client is not None:
+                Utils.create_task(_client.release())
 
         return self._mysql_rw_pool.get_transaction()
 
@@ -756,7 +762,7 @@ class DBClient(_ClientBase, AsyncContextManager):
                 await self._close_conn(True)
 
                 if times < MYSQL_ERROR_RETRY_COUNT:
-                    Utils.log.exception(err)
+                    Utils.log.error(err)
                 else:
                     raise err
 
