@@ -8,7 +8,7 @@ import asyncio
 from threading import Thread as _Thread
 from concurrent.futures import ThreadPoolExecutor
 
-from hagworm.extend.interface import RunnableInterface, TaskInterface
+from ..interface import RunnableInterface, TaskInterface
 
 from .base import Utils
 
