@@ -6,7 +6,7 @@ import aiosmtplib
 
 from email.message import EmailMessage
 
-from hagworm.extend.asyncio.base import Utils
+from .base import Utils
 
 
 class EmailBody:
