@@ -8,12 +8,11 @@ import aiohttp
 
 from contextlib import contextmanager
 
-from hagworm.extend.struct import Enum
-from hagworm.extend.base import ContextManager
-from hagworm.extend.asyncio.base import AsyncCirculatorForSecond
-from hagworm.extend.asyncio.buffer import FileBuffer
+from ..struct import Enum
+from ..interface import ContextManager
 
-from .base import Utils
+from .base import Utils, AsyncCirculatorForSecond
+from .buffer import FileBuffer
 
 
 class STATE(Enum):
