@@ -10,7 +10,7 @@ from collections import OrderedDict
 from apscheduler.schedulers.asyncio import AsyncIOScheduler
 from apscheduler.triggers.cron import CronTrigger
 
-from hagworm.extend.interface import TaskInterface
+from ..interface import TaskInterface
 
 from .base import Utils, FutureWithTask
 
