@@ -2,9 +2,10 @@
 
 __author__ = r'wsb310@gmail.com'
 
-from .base import Utils, AsyncContextManager
+from .base import Utils
 
-from hagworm.extend.transaction import TransactionAbstract
+from ..interface import AsyncContextManager
+from ..transaction import TransactionAbstract
 
 
 class Transaction(TransactionAbstract, AsyncContextManager):
