@@ -6,6 +6,7 @@ import os
 import re
 import sys
 import platform
+import traceback
 import uuid
 import time
 import math
@@ -34,12 +35,11 @@ import jwt
 import yaml
 import loguru
 import warnings
-import traceback
 import xmltodict
 import xml.dom.minidom
 
 from datetime import datetime, timedelta
-from contextlib import contextmanager, closing
+from contextlib import closing
 from collections import OrderedDict
 from collections.abc import Iterable
 from cachetools import cached, TTLCache
@@ -48,7 +48,6 @@ from zipfile import ZipFile, ZIP_DEFLATED
 from stdnum import luhn
 from dateutil.parser import parse as date_parse
 
-from .error import BaseError
 from .text import StrUtils
 
 
@@ -984,110 +983,6 @@ class Utils:
                 process.kill()
 
 
-class Ignore(BaseError):
-    """可忽略的异常
-
-    用于with语句块跳出，或者需要跳出多层逻辑的情况
-
-    """
-
-    def __init__(self, *args, layers=1, **kwargs):
-
-        super().__init__(*args, **kwargs)
-
-        self._layers = layers
-
-        if err := str(self):
-            Utils.log.warning(err)
-
-    def throw(self):
-
-        if self._layers > 0:
-            self._layers -= 1
-
-        return self._layers != 0
-
-
-@contextmanager
-def catch_warning():
-    """异常捕获，打印warning级日志
-
-    通过with语句捕获异常，代码更清晰，还可以使用Ignore异常安全的跳出with代码块
-
-    """
-
-    try:
-
-        yield
-
-    except Ignore as err:
-
-        if err.throw():
-            raise err
-
-    except Exception as err:
-
-        Utils.log.warning(err)
-
-
-@contextmanager
-def catch_error():
-    """异常捕获，打印error级日志
-
-    通过with语句捕获异常，代码更清晰，还可以使用Ignore异常安全的跳出with代码块
-
-    """
-
-    try:
-
-        yield
-
-    except Ignore as err:
-
-        if err.throw():
-            raise err
-
-    except Exception as err:
-
-        Utils.log.exception(err)
-
-
-class ContextManager:
-    """上下文资源管理器
-
-    子类通过实现_context_release接口，方便的实现with语句管理上下文资源释放
-
-    """
-
-    def __enter__(self):
-
-        self._context_initialize()
-
-        return self
-
-    def __exit__(self, exc_type, exc_value, _traceback):
-
-        self._context_release()
-
-        if exc_type is Ignore:
-
-            return not exc_value.throw()
-
-        elif exc_value:
-
-            Utils.log.exception(traceback.format_exc())
-
-            return True
-
-    def _context_initialize(self):
-
-        pass
-
-    def _context_release(self):
-
-        raise NotImplementedError()
-
-
 class FuncWrapper:
     """函数包装器
 
@@ -1104,8 +999,8 @@ class FuncWrapper:
         for func in self._callables:
             try:
                 func(*args, **kwargs)
-            except Exception as err:
-                Utils.log.error(err)
+            except:
+                Utils.log.error(traceback.format_exc())
 
     @property
     def is_valid(self):
