@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+__author__ = r'wsb310@gmail.com'
+
 import qrcode
 
 from io import BytesIO
@@ -9,19 +11,21 @@ from qrcode.image.svg import SvgPathImage
 class QRCode:
 
     @staticmethod
-    def make(data):
+    def make(data, **kwargs):
 
         code_img = BytesIO()
 
-        qrcode.make(data).save(code_img)
+        qrcode.make(data, **kwargs).save(code_img)
 
         return code_img.getvalue()
 
     @staticmethod
-    def make_svg(data):
+    def make_svg(data, **kwargs):
 
         code_img = BytesIO()
 
-        qrcode.make(data, image_factory=SvgPathImage).save(code_img)
+        kwargs[r'image_factory'] = SvgPathImage
+
+        qrcode.make(data, **kwargs).save(code_img)
 
         return code_img.getvalue().decode()
