@@ -14,16 +14,26 @@ from starlette.concurrency import run_in_threadpool
 from fastapi import __version__ as fastapi_version
 from fastapi.encoders import jsonable_encoder
 from fastapi.exceptions import RequestValidationError
+from fastapi.openapi.docs import get_swagger_ui_html
 
-from hagworm import hagworm_label, hagworm_slogan
-from hagworm import __version__ as hagworm_version
-from hagworm.extend.asyncio.base import Utils, install_uvloop
-from hagworm.extend.logging import DEFAULT_LOG_FILE_NAME, DEFAULT_LOG_FILE_ROTATOR, init_logger
+from ... import hagworm_label, hagworm_slogan
+from ... import __version__ as hagworm_version
+
+from ...extend.asyncio.base import Utils, install_uvloop
+from ...extend.logging import DEFAULT_LOG_FILE_NAME, DEFAULT_LOG_FILE_ROTATOR, init_logger
 
 from .response import Response, ErrorResponse
 from .middleware import RequestIDMiddleware
 
 
+get_swagger_ui_html.__kwdefaults__.update(
+    {
+        r'swagger_js_url': r'https://cdn.staticfile.org/swagger-ui/4.11.1/swagger-ui-bundle.min.js',
+        r'swagger_css_url': r'https://cdn.staticfile.org/swagger-ui/4.11.1/swagger-ui.min.css',
+    }
+)
+
+
 DEFAULT_HEADERS = [(r'Server', hagworm_label)]
 
 
