@@ -4,8 +4,8 @@ __author__ = r'wsb310@gmail.com'
 
 from fastapi.responses import UJSONResponse
 
-from hagworm.extend.base import Ignore
-from hagworm.extend.struct import Result
+from ...extend.error import Ignore
+from ...extend.struct import Result
 
 from .middleware import RequestIDMiddleware
 
