@@ -4,7 +4,7 @@ __author__ = r'wsb310@gmail.com'
 
 from uvicorn.workers import UvicornWorker
 
-from hagworm.frame.fastapi.base import DEFAULT_HEADERS
+from .fastapi.base import DEFAULT_HEADERS
 
 
 DEFAULT_LOG_CONFIG = {
